# 2021 TrustedSec
# Contributors: @nyxgeek, @rootsecdev
#
# The purpose of this script is to enumerate BASIC INFORMATION about an Azure Tenant to aid in scoping
#Installation of the following modules are required
#Install-Module -Name Az -AllowClobber
#Install-Module -Name AzureAD -AllowClobber
Connect-AzureAD
Connect-AzAccount

# Export IP Information from all subscriptions
Get-AzSubscription | foreach-object { 
 
    Write-Verbose -Message "Changing to Subscription $($_.Name)" -Verbose 
 
$s = Select-AzSubscription -TenantId $_.TenantId -Subscription $_.Id -Force 
    $Name     = $_.Name 
    $TenantId = $_.TenantId 
 
 
   Get-AzPublicIpAddress | select -Property @{name='subscription';e={$name}}, *name,ipaddress, PublicIpAllocationMethod,location,@{name='sku';e={$_.sku.name}},@{name='dns';e={$_.dnssettings.domainnamelabel}} -OutVariable ra 
 
 
} | Export-Csv publicipazure.csv -NoTypeInformation

#Collect list of Licensing on Azure Tenant
$allSKUs=Get-AzureADSubscribedSku
$licArray = @()
for($i = 0; $i -lt $allSKUs.Count; $i++)
{
$licArray += "Service Plan: " + $allSKUs[$i].SkuPartNumber
$licArray +=  Get-AzureADSubscribedSku -ObjectID $allSKUs[$i].ObjectID | Select -ExpandProperty ServicePlans
$licArray +=  ""
}
$licArray | Out-File License.txt

#Collect resources from all subscriptions that exist in a tenant
$date = Get-Date -UFormat("%m-%d-%y")
$currentDir = $(Get-Location).Path
$oFile = "$($currentDir)\List_Of_All_Azure_Resources_$($date).csv"
 

 "SubscriptName, ResourceGroupName,ResourceName,ResourceType,Tags" | Out-File $oFile -Append -Encoding ascii
 
Get-AzSubscription | ForEach-Object{
    $subscriptionId = $_.Id
    $subscriptionName = $_.Name
     
    Set-AzContext -SubscriptionId $subscriptionId
    Get-AzResourceGroup | ForEach-Object{
        $resourceGroupName = $_.ResourceGroupName
        Get-AzResource -ResourceGroupName $resourceGroupName | ForEach-Object{
            $resourceName = $_.Name
              
            $resourceType = $_.ResourceType
             
            if(!([string]::IsNullOrEmpty($_.Tags))){
                $tags = @()
                $_.Tags.GetEnumerator() |ForEach-Object {
                    [string]$tags += $_.key+ "=" + $_.value+ ";"
                }
            }
            else{
                $tags = ""
            }
            "$subscriptionName,$resourceGroupName,$resourceName,$resourceType,$tags" | Out-File $oFile -Append -Encoding ascii
        }
    }
}
